@@ -1,13 +1,17 @@
 package Log::ger::Output::ArrayRotate;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-08'; # DATE
+our $DATE = '2020-03-09'; # DATE
 our $DIST = 'Log-ger-Output-ArrayRotate'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
 
+sub meta { +{
+    v => 1,
+} }
+
 sub get_hooks {
     my %plugin_conf = @_;
 
@@ -19,7 +23,7 @@ sub get_hooks {
             __PACKAGE__, # key
             50,          # priority
             sub {        # hook
-                my %hook_args = @_;
+                my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
 
                 my $outputter = sub {
                     my ($ctx, $msg) = @_;
@@ -48,7 +52,7 @@ Log::ger::Output::ArrayRotate - Log to array, rotating old elements
 
 =head1 VERSION
 
-This document describes version 0.002 of Log::ger::Output::ArrayRotate (from Perl distribution Log-ger-Output-ArrayRotate), released on 2020-03-08.
+This document describes version 0.003 of Log::ger::Output::ArrayRotate (from Perl distribution Log-ger-Output-ArrayRotate), released on 2020-03-09.
 
 =head1 SYNOPSIS
 
